import request from '@/utils/request'
//-----------------------------------岗位管理-----------------------------
// 添加岗位
export const useAddJob = ({
  address,
  addressDetail,
  details,
  jobName,
  startTime,
  endTime,
  jobTips,
  jobType,
  minSalary,
  maxSalary,
  minNumber,
  maxNumber,
  requirement,
  userId,
  encoding
}) =>
  request.post('recruitment/add_job', {
    address,
    addressDetail,
    details,
    jobName,
    startTime,
    endTime,
    jobTips,
    jobType,
    minSalary,
    maxSalary,
    minNumber,
    maxNumber,
    requirement,
    userId,
    encoding
  })
// 根据公司编码获取岗位列表
export const useGetJobList = (encoding) =>
  request.get('recruitment/get_jobList', {
    params: {
      encoding: encoding
    }
  })
// 根据岗位id获取岗位详情
export const useGetJobById = (id) =>
  request.get('recruitment/get_jobById', {
    params: {
      id: id
    }
  })
// 编辑岗位
export const useUpdateJob = ({
  id,
  address,
  addressDetail,
  details,
  jobName,
  startTime,
  endTime,
  jobTips,
  jobType,
  minSalary,
  maxSalary,
  minNumber,
  maxNumber,
  requirement,
  userId,
  encoding
}) =>
  request.post('recruitment/update_job', {
    id,
    address,
    addressDetail,
    details,
    jobName,
    startTime,
    endTime,
    jobTips,
    jobType,
    minSalary,
    maxSalary,
    minNumber,
    maxNumber,
    requirement,
    userId,
    encoding
  })
// 搜索岗位
export const useSearchJob = (jobName, jobType, encoding) =>
  request.get('recruitment/search_job', {
    params: {
      jobName: jobName,
      jobType: jobType,
      encoding: encoding
    }
  })
// 根据岗位id修改岗位状态
export const useChangeJobStatus = (id, userId) =>
  request.post('recruitment/update_jobStatus', {
    id,
    userId
  })
// 根据岗位id删除岗位信息
export const useDelJob = (id) =>
  request.delete('recruitment/delete_job', {
    params: {
      id: id
    }
  })
//------------------------------面试设置--------------------------
// 添加面试设置
export const useAddJobSetting = ({
  jobId,
  imagesId,
  jobPromote,
  backgroundId,
  logoId,
  Professional,
  Comprehensive,
  Psychology,
  userId,
  encoding
}) =>
  request.post('recruitment/add_jobSetting', {
    jobId,
    imagesId,
    backgroundId,
    jobPromote,
    logoId,
    Professional,
    Comprehensive,
    Psychology,
    userId,
    encoding
  })
// 根据公司编码获取面试设置列表
export const useGetJobSettingList = (encoding) =>
  request.get('recruitment/get_jobSettingList', {
    params: {
      encoding: encoding
    }
  })
// 根据面试设置id删除面试设置
export const useDeleteJobSetting = (id) =>
  request.delete('recruitment/delete_jobJobSetting', {
    params: {
      id: id
    }
  })
// 编辑面试设置
export const useUpdateJobSetting = ({
  id,
  jobId,
  imagesId,
  jobPromote,
  backgroundId,
  logoId,
  professional,
  comprehensive,
  psychology,
  userId,
  encoding
}) =>
  request.post('recruitment/update_jobJobSetting', {
    id,
    jobId,
    imagesId,
    jobPromote,
    backgroundId,
    logoId,
    professional,
    comprehensive,
    psychology,
    userId,
    encoding
  })
// 根据岗位名称搜索面试设置
export const useSearchSettings = (jobName, encoding) =>
  request.get('recruitment/search_setting', {
    params: {
      jobName: jobName,
      encoding: encoding
    }
  })
//------------------------------公司详情---------------------
// 根据公司编码获取公司详情
export const useGetCompanyDetail = (encoding) =>
  request.get('recruitment/get_companyDetail', {
    params: {
      encoding: encoding
    }
  })
// 修改公司详情
export const useUploadCompanyDetail = ({
  address,
  addressDetail,
  companyDetail,
  companyName,
  creditCode,
  encoding,
  established,
  subImages,
  legalRepresentative,
  treatment,
  registeredCapital,
  userId,
  subLogo,
  type,
  staffNumber,
  companyAllName
}) =>
  request.post('recruitment/update_companyDetail', {
    address,
    addressDetail,
    companyDetail,
    companyName,
    creditCode,
    encoding,
    established,
    images: subImages,
    legalRepresentative,
    treatment,
    registeredCapital,
    userId,
    type,
    companyLogo: subLogo,
    staffNumber,
    companyAllName
  })
//招聘发布
export const addJobPosting = ({
  name,
  startTime,
  endTime,
  checkList,
  userId,
  encoding
}) =>
  request.post('/recruitment/add_jobPosting', {
    name,
    startTime,
    endTime,
    checkList,
    userId,
    encoding
  })
export const updateJobPosting = ({
  id,
  name,
  startTime,
  endTime,
  checkList,
  userId,
  status
}) =>
  request.post('/recruitment/update_jobPosting', {
    id,
    name,
    startTime,
    endTime,
    checkList,
    userId,
    status
  })

export const deleteJobPosting = (id) =>
  request.delete('/recruitment/delete_jobPosting', {
    params: {
      id: id
    }
  })
export const getJobPostingList = (encoding) =>
  request.get('/recruitment/get_jobPostingList', {
    params: {
      encoding: encoding
    }
  })

//获取求职者信息
export const getApplicationList = (encoding, jobId) =>
  request.get('/recruitment/getApplicationList', {
    params: {
      encoding: encoding,
      jobId: jobId
    }
  })

//搜索求职者
export const searchApplicationByName = (searchName, encoding) =>
  request.get('/recruitment/searchApplicationByName', {
    params: {
      searchName: searchName,
      encoding: encoding
    }
  })

export const disagreeApplication = (id) =>
  request.get('/recruitment/disagreeApplication', {
    params: {
      id: id
    }
  })

export const getJobSettingByJobId = (jobId) =>
  request.get('/recruitment/get_jobSettingByJobId', {
    params: {
      jobId: jobId
    }
  })
