import { useUserStore } from '@/stores'
import axios from 'axios'
import router from '@/router'

const baseURL = 'http://localhost:8080'

const instance = axios.create({
  baseURL,
  timeout: 100000
})

instance.interceptors.request.use(
  (config) => {
    const userStore = useUserStore()
    if (userStore.token) {
      config.headers.Authorization = userStore.token
    }
    return config
  },
  (err) => Promise.reject(err)
)

instance.interceptors.response.use(
  (res) => {
    if (res.data.code === 0) {
      return res
    }
    if (res.data.code === 401) {
      ElMessage.error(res.data.message)
      router.replace('/login')
    }
    ElMessage.error(res.data.message)
    return Promise.reject(res)
  },
  (err) => {
    if (err.response?.status === 401) {
      router.replace('/login')
    }
    return Promise.reject(err)
  }
)

export default instance
export { baseURL }
